@@ -21,13 +21,17 @@ public:
         Register,
         Unregister,  ///< unregistration requested by client
         ForceUnregister, ///< unregistration triggered by distributor
+        SilentUnregister, ///< unregistration for moving to a different push provider
         Connect,
         Disconnect,
-        ChangePushProvider
+        ChangePushProvider,
+        MessageAck,
+        ChangeUrgency,
+        Wait,
     } type = NoCommand;
     Client client;
     QDBusMessage reply;
-    QString pushProvider;
+    QString value;
 };
 
 }
